#include <QtGui>
#include <QDebug>
#include <QFileInfo>
#include <QListWidgetItem>
#include <QIcon>

#include "filedialog.h"


FileDialog::FileDialog(QWidget *parent)
    : QWidget(parent)
{
    qDebug("FileDialog(QWidget *parent)");
    //Dialog布局
    setWindowFlags(Qt::CustomizeWindowHint|Qt::FramelessWindowHint);
    resize(320, 240);
    this->move(0,0);
    setAutoFillBackground(true);
    QPixmap pixmap(":/images/beijing.jpg");
    QPalette palette;
    palette.setBrush(backgroundRole(), QBrush(pixmap));
    setPalette(palette);
    dir="/";
    dir_name_edit=new QLineEdit;
    ok_button=new QPushButton(tr("&Ok"));
    cancel_button=new QPushButton(tr("&Cancle")) ;
    QHBoxLayout *belowlayout=new QHBoxLayout;
    belowlayout->addWidget(dir_name_edit);
    belowlayout->addWidget(ok_button);
    belowlayout->addWidget(cancel_button);
    dir_name_edit->setText(dir);

    dir_list=new QListWidget;
    dir_list->setViewMode(QListView::ListMode);
    dir_list->setMovement(QListView::Static);
    dir_list->setResizeMode(QListView::Fixed);
    dir_list->setFocusPolicy(Qt::NoFocus);

    QGridLayout *layout=new QGridLayout;
    layout->addLayout(belowlayout,0,0,1,3);
    layout->addWidget(dir_list,1,0,3,3);
    this->setLayout(layout);

    //显示根目录文件夹列表
    dirlist<<dir;
    num=0;
    QDir picdir(dir);
    picdir.setFilter(QDir::Dirs|QDir::NoDotAndDotDot);
    QFileInfoList list = picdir.entryInfoList();
    for(int i=0;i<list.size();i++)
    {
        QFileInfo fileInfo0 = list.at(i);
        QString  path=fileInfo0.filePath();
        path.replace(dir, QString(""));
        path=path.remove(QChar('/'),Qt::CaseInsensitive);
        QListWidgetItem *item = new QListWidgetItem;
        item->setIcon(QIcon(":/images/folder.png"));
        item->setText(path);
        dir_list->insertItem((i+1),item);
    }
    //建立信号槽
    connect(dir_list,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(oneClick(QListWidgetItem*)));
    connect(dir_list,SIGNAL(itemDoubleClicked(QListWidgetItem*)),this,SLOT(doubleClick(QListWidgetItem*)));
    connect(ok_button,SIGNAL(clicked()),this,SLOT(chooseNewDir()));
    connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancleChoose()));
}

//单击文件夹列表
void FileDialog::oneClick(QListWidgetItem* item_new)
{
    qDebug("oneClick(QListWidgetItem* item_new)");
    QString dir_name1;
    dir_name1=item_new->text();
    if(dir_name1==".")
    {
        dir_name_lineE=dir;
    }
    else if(dir_name1=="..")
    {
        dir_name_lineE=dirlist.at(num-1);
    }
    else
    {
        dir_name_lineE=dir;
        if(dir_name_lineE!="/")
        {
            dir_name_lineE+="/";
        }
        dir_name_lineE+=dir_name1;
    }
    dir_name_edit->setText(dir_name_lineE);
}

//双击文件夹列表
void FileDialog::doubleClick(QListWidgetItem* item_new)
{
    qDebug("doubleClick(QListWidgetItem* item_new)");
    QString dir_name2;
    dir_name2=item_new->text();
    if(dir_name2==".")
    {
        dir_name0=dir;
    }
    else if(dir_name2=="..")
    {
        num--;
        dir_name0=dirlist.at(num);
        QStringList dirlist_cache;
        for(int i=0;i<=num;i++)
        {
            dirlist_cache<<dirlist.at(i);
        }
        dirlist.clear();
        dirlist<<dirlist_cache;
        dir=dir_name0;
    }
    else
    {
        dir_name0=dir;
        if(dir_name0!="/")
        {
            dir_name0+="/";
        }
        dir_name0+=dir_name2;
        dir=dir_name0;
        dirlist<<dir;
        num++;
    }
    QDir picdir(dir);
    if(dir=="/")
    {
        picdir.setFilter(QDir::Dirs|QDir::NoDotAndDotDot);
    }
    else
    {
        picdir.setFilter(QDir::Dirs);
    }
    QFileInfoList list = picdir.entryInfoList();
    dir_list->clear();
    for(int i=0;i<list.size();i++)
    {
        QFileInfo fileInfo0 = list.at(i);
        QString  path=fileInfo0.filePath();
        path.replace(dir, QString(""));
        path=path.remove(QChar('/'),Qt::CaseInsensitive);
        QListWidgetItem *item = new QListWidgetItem;
        item->setIcon(QIcon(":/folder.png"));
        item->setText(path);
        dir_list->insertItem((i+1),item);
    }
}

//OK键选择返回新图片文件夹路径
void FileDialog::chooseNewDir()
{
    qDebug("chooseNewDir()");
    emit newDir(dir_name_lineE);
    this->close();
}

//Cancle取消选择文件夹
void FileDialog::cancleChoose()
{
    qDebug("cancleChoose()");
    QString  nullDir=NULL;
    emit newDir(nullDir);
    this->close();
}
