#include <QtGui>

#include "window.h"
#include "renderarea.h"
#include "showlist.h"

Window::Window()
{
    this->move(0,0);
    resize(320, 240);
    setWindowFlags(Qt::CustomizeWindowHint|Qt::FramelessWindowHint);
    setAutoFillBackground(true);
    QPixmap pixmap(":/images/bphoto.png");
    QPalette palette;
    palette.setBrush(backgroundRole(), QBrush(pixmap));
    setPalette(palette);
    showList = new ShowList;
    renderArea = new RenderArea;
    connect(renderArea, SIGNAL(getDir(QString,int)),showList, SLOT(pathList(QString,int)));
    connect(showList, SIGNAL(ListDir(int)),renderArea,SLOT(getShowList(int)));
    connect(showList, SIGNAL(ListDir(int)),this,SLOT(backRen(int)));
    connect(renderArea, SIGNAL(returnFlag(bool)),this, SLOT(buttonFlag(bool)));
    reTurn=renderArea->init();
    frontbutton=new QPushButton(tr("上一张"),this);
    nextbutton=new QPushButton(tr("下一张"),this);
    blowupbutton=new QPushButton(tr("放大"),this);
    reducebutton=new QPushButton(tr("缩小"),this);
    findbutton=new QPushButton(tr("查找"),this);
    transformbutton=new QPushButton(tr("旋转"),this);
    exitbutton=new QPushButton(tr("主菜单"),this);
    autobutton=new QPushButton(tr("播放"),this);
    backbutton=new QPushButton(tr("列表"),this);

    frontbutton->setMaximumSize(44,25);
    frontbutton->setMinimumSize(44,25);
    frontbutton->setStyleSheet("background-color: rgb(255,255,255,100);");

    nextbutton->setMaximumSize(44,25);
    nextbutton->setMinimumSize(44,25);
    nextbutton->setStyleSheet("background-color: rgb(255,255,255,100);");

    blowupbutton->setMaximumSize(44,25);
    blowupbutton->setMinimumSize(44,25);
    blowupbutton->setStyleSheet("background-color: rgb(255,255,255,100);");

    reducebutton->setMaximumSize(44,25);
    reducebutton->setMinimumSize(44,25);
    reducebutton->setStyleSheet("background-color: rgb(255,255,255,100);");

    findbutton->setMaximumSize(44,25);
    findbutton->setMinimumSize(44,25);
    findbutton->setStyleSheet("background-color: rgb(255,255,255,100);");

    transformbutton->setMaximumSize(44,25);
    transformbutton->setMinimumSize(44,25);
    transformbutton->setStyleSheet("background-color: rgb(255,255,255,100);");

    exitbutton->setMaximumSize(70,25);
    exitbutton->setMinimumSize(70,25);
    exitbutton->setStyleSheet("background-color: rgb(255,255,255,100);");

    autobutton->setMaximumSize(44,25);
    autobutton->setMinimumSize(44,25);
    autobutton->setStyleSheet("background-color: rgb(255,255,255,100);");

    backbutton->setMaximumSize(44,25);
    backbutton->setMinimumSize(44,25);
    backbutton->setStyleSheet("background-color: rgb(255,255,255,100);");



    if(reTurn==false)
    {
        backbutton->setDisabled(true);
        autobutton->setDisabled(true);
        frontbutton->setDisabled(true);
        nextbutton->setDisabled(true);
    }
    comboBox =new QPushButton(this);
    comboBox->setText(QObject::tr("效果选择"));
    comboBox->setMaximumSize(70,25);
    comboBox->setStyleSheet("background-color: rgb(255,255,255,100);" );

    chooseN = new QFrame;
    chooseN->resize(320, 240);
    chooseN->setWindowFlags(Qt::CustomizeWindowHint|Qt::FramelessWindowHint);
    chooseN->setObjectName("choose-frame");
    chooseN->setAutoFillBackground(true);
    QPixmap pixmap1(":/images/beijing.jpg");
    QPalette palette1;
    palette1.setBrush(backgroundRole(), QBrush(pixmap1));
    chooseN->setPalette(palette1);
    choose0=new QPushButton(tr("直接\n切换"), chooseN);
    choose1=new QPushButton(tr("旋转\n缩放"), chooseN);
    choose2=new QPushButton(tr("淡入\n淡出"), chooseN);
    choose3=new QPushButton(tr("竖直\n滑动"), chooseN);
    choose4=new QPushButton(tr("水平\n滑动"), chooseN);
    choose5=new QPushButton(tr("卷书\n翻页"), chooseN);
    choose6=new QPushButton(tr("随机\n切换"), chooseN);

    choose0->setGeometry(30,50,50,50);
    choose1->setGeometry(100,50,50,50);
    choose2->setGeometry(170,50,50,50);
    choose3->setGeometry(240,50,50,50);
    choose4->setGeometry(30,120,50,50);
    choose5->setGeometry(100,120,50,50);
    choose6->setGeometry(170,120,50,50);

    choose0->setStyleSheet("background-color: rgb(255,255,255,180);");
    choose1->setStyleSheet("background-color: rgb(255,255,255,180);");
    choose2->setStyleSheet("background-color: rgb(255,255,255,180);");
    choose3->setStyleSheet("background-color: rgb(255,255,255,180);");
    choose4->setStyleSheet("background-color: rgb(255,255,255,180);");
    choose5->setStyleSheet("background-color: rgb(255,255,255,180);");
    choose6->setStyleSheet("background-color: rgb(255,255,255,180);");

    belowlayout=new QHBoxLayout;
    belowlayout1=new QHBoxLayout;
    mainlayout=new QGridLayout;

    belowlayout->addStretch();
    belowlayout->addWidget(comboBox);
    belowlayout->addWidget(backbutton);
    belowlayout->addWidget(frontbutton);
    belowlayout->addWidget(autobutton);
    belowlayout->addWidget(nextbutton);
    belowlayout->addStretch();

    belowlayout1->addStretch();
    belowlayout1->addWidget(exitbutton);
    belowlayout1->addWidget(findbutton);
    belowlayout1->addWidget(reducebutton);
    belowlayout1->addWidget(transformbutton);
    belowlayout1->addWidget(blowupbutton);
    belowlayout1->addStretch();

    mainlayout->addWidget(renderArea,0,0,6,1);
    mainlayout->addLayout(belowlayout,6,0,Qt::AlignRight);
    mainlayout->addLayout(belowlayout1,7,0,Qt::AlignRight);
    setLayout(mainlayout);

    timer = new QTimer( this );
    timer_hide= new QTimer( this );

    connect( timer, SIGNAL(timeout()),this, SLOT(play()));             //此信号槽定时触发下一张图片切换
    connect( timer_hide, SIGNAL(timeout()),this, SLOT(btn_hide()) );   //此信号槽触发按键自动隐藏
    connect(frontbutton,SIGNAL(clicked()), this,SLOT( predisplay() )); //此信号槽触发切换前一张图片
    connect(nextbutton,SIGNAL(clicked()), this,SLOT(nextdisplay()));   //此信号槽触发切换后一张图片
    connect(blowupbutton,SIGNAL(clicked()), this,SLOT(blow()));        //此信号槽触发放大图片功能
    connect(reducebutton,SIGNAL(clicked()), this,SLOT(reduce()));      //此信号槽触发缩小图片功能
    connect(exitbutton,SIGNAL(clicked()),this,SLOT(ToReturn()));          //此信号槽触发退出程序
    connect(findbutton,SIGNAL(clicked()),this,SLOT(find()));           //此信号槽触发查找新图片路径
    connect(transformbutton,SIGNAL(clicked()),this,SLOT(transform_btn()));//此信号槽触发图片旋转功能
    connect(autobutton,SIGNAL(clicked()),this,SLOT(autoplay()));       //此信号槽触发开启定时器timer
    connect(backbutton,SIGNAL(clicked()),this,SLOT(backList()));
    connect(comboBox,SIGNAL(clicked()),this,SLOT(chooseS()));
    connect(this, SIGNAL(chooseNum(int)), renderArea, SLOT(changestytle(int)));//此信号槽同步combobox的选项切换
    connect(this, SIGNAL(chooseNum(int)), this, SLOT(changestytle(int)));//此信号槽触发combobox其他选项时屏蔽按键
    connect(choose0,SIGNAL(clicked()), this,SLOT(choose00()));      //此信号槽用于切换到图片列表功能
    connect(choose1,SIGNAL(clicked()), this,SLOT(choose11()));
    connect(choose2,SIGNAL(clicked()), this,SLOT(choose22()));
    connect(choose3,SIGNAL(clicked()), this,SLOT(choose33()));
    connect(choose4,SIGNAL(clicked()), this,SLOT(choose44()));
    connect(choose5,SIGNAL(clicked()), this,SLOT(choose55()));
    connect(choose6,SIGNAL(clicked()), this,SLOT(choose66()));
    qDebug("window-init");
}


//按键触发放大槽函数
void Window::blow()
{
    timer_hide->stop();
    timer_hide->start(5000);
    timer->stop();
    renderArea->Blow();
}

//按键触发缩小槽函数
void Window::reduce()
{
    timer_hide->stop();
    timer_hide->start(5000);
    timer->stop();
    renderArea->Reduce();
}

//按键触发前一张图片切换槽函数
void Window::predisplay()
{
    timer_hide->stop();
    timer_hide->start(5000);
    timer->stop();
    renderArea->pre_area();
}

//按键触发后一张图片槽函数
void Window::nextdisplay()
{
    timer_hide->stop();
    timer_hide->start(5000);
    timer->stop();
    renderArea->fun_area();
}

//按键触发更改图片所在文件夹路径槽函数
void Window::find()
{
    timer_hide->stop();
    timer->stop();
    renderArea->open();
    qDebug("onlyone");
    timer_hide->start(5000);
}

//按键触发图片旋转功能槽函数
void Window::transform_btn()
{
    timer_hide->stop();
    timer_hide->start(5000);
    timer->stop();
    renderArea->transformbutton();
}

//按键触发自动播放功能开启定时器槽函数
void Window::autoplay()
{
    timer->start(6000);
}

//此槽函数在定时之后自动切换下一张图片
void Window::play()
{
    renderArea->fun_area();
}

//设置键盘上各个按键的快捷方式
void Window::keyPressEvent(QKeyEvent *event)
{
    if ( event->key() == Qt::Key_Right)
    {
        predisplay();  
    }
    if ( event->key() == Qt::Key_Left)
    {
        nextdisplay();
    }
     if ( event->key() == Qt::Key_Up)
    {
        blow();
    }
      if ( event->key() == Qt::Key_Down)
    {
        reduce();
    }
      if(event->key() == Qt::Key_F)
      {
          find();
      }
      if(event->key() == Qt::Key_Escape)
      {
          timer_hide->stop();
          timer->stop();
          close();
      }
  }

//设置鼠标点击事件实现按键点击显示
void Window::mousePressEvent(QMouseEvent *)
{
    qDebug("Window::mousePressEvent(QMouseEvent *event)");
    qDebug("mouse");
    QPixmap pixmap(":/images/bphoto.png");
    QPalette palette;
    palette.setBrush(backgroundRole(), QBrush(pixmap));
    setPalette(palette);
    frontbutton->setVisible(true);
    nextbutton->setVisible(true);
    blowupbutton->setVisible(true);
    reducebutton->setVisible(true);
    findbutton->setVisible(true);
    transformbutton->setVisible(true);
    exitbutton->setVisible(true);
    autobutton->setVisible(true);
    backbutton->setVisible(true);
    comboBox->setVisible(true);
    timer_hide->stop();
    timer_hide->start(5000);
}

//此定时器槽函数实现按键定时自动隐藏
void Window::btn_hide()
{
    qDebug("Window::btn_hide()");
    QPixmap pixmap(":/images/bphoto1.png");
    QPalette palette;
    palette.setBrush(backgroundRole(), QBrush(pixmap));
    setPalette(palette);
    timer_hide->stop();
    frontbutton->setVisible(false);
    nextbutton->setVisible(false);
    blowupbutton->setVisible(false);
    reducebutton->setVisible(false);
    findbutton->setVisible(false);
    transformbutton->setVisible(false);
    exitbutton->setVisible(false);
    autobutton->setVisible(false);
    backbutton->setVisible(false);
    comboBox->setVisible(false);
}

//此槽函数实现选择图片切换效果之后触发按键显示延时
void Window::changestytle(int choose)
{
    qDebug("%d",choose);
    timer_hide->stop();
    timer_hide->start(5000);
}

//槽函数用于切换到showList界面
void Window::backList()
{
    qDebug("Window::backList()");
    timer->stop();
    timer_hide->stop();
    mainlayout->removeWidget(renderArea);
    mainlayout->addWidget(showList,0,0,8,1);
    setLayout(mainlayout);
    showList->picList();
    showList->show();
}

//槽函数用于切换到renderArea界面
void Window::backRen(int)
{
    qDebug("Window::backRen(int i)");
    qDebug("OK");
    timer->stop();
    timer_hide->stop();
    mainlayout->removeWidget(showList);
    mainlayout->addWidget(renderArea,0,0,6,1);
    showList->hide();
    btn_hide();
    setLayout(mainlayout);
}

//槽函数用于关闭此界面返回主界面
void Window::ToReturn()
{

    timer_hide->stop();
    timer->stop();
    this->close();
}

void Window::buttonFlag(bool returnFlag)
{
    reTurn1=returnFlag;
    if(reTurn1==false && reTurn==false)
    {
        qDebug("0-1");
        backbutton->setDisabled(true);
        autobutton->setDisabled(true);
        frontbutton->setDisabled(true);
        nextbutton->setDisabled(true);
    }
    else
    {
        reTurn=true;
        backbutton->setDisabled(false);
        autobutton->setDisabled(false);
        frontbutton->setDisabled(false);
        nextbutton->setDisabled(false);

    }

}

void Window::chooseS()
{
    timer_hide->stop();
    timer->stop();
    chooseN->show();
    chooseN->move(0,0);
}


void Window::choose00()
{
    timer_hide->start(5000);
    emit chooseNum(0);
    chooseN->hide();
    comboBox->setText(tr("直接切换"));
}

void Window::choose11()
{
    timer_hide->start(5000);
    emit chooseNum(1);
    chooseN->hide();
    comboBox->setText(tr("旋转缩放"));
}

void Window::choose22()
{
    timer_hide->start(5000);
    emit chooseNum(2);
    chooseN->hide();
    comboBox->setText(tr("淡入淡出"));
}

void Window::choose33()
{
    timer_hide->start(5000);
    emit chooseNum(3);
    chooseN->hide();
    comboBox->setText(tr("竖直滑动"));
}

void Window::choose44()
{
    timer_hide->start(5000);
    emit chooseNum(4);
    chooseN->hide();
    comboBox->setText(tr("水平滑动"));
}

void Window::choose55()
{
    timer_hide->start(5000);
    emit chooseNum(5);
    chooseN->hide();
    comboBox->setText(tr("卷书翻页"));
}

void Window::choose66()
{
    timer_hide->start(5000);
    emit chooseNum(6);
    chooseN->hide();
    comboBox->setText(tr("随机切换"));
}




